@@ -45,12 +45,12 @@ def correct(text: str, matches: [Match]) -> str:
     """Automatically apply suggestions to the text."""
     ltext = list(text)
     matches = [match for match in matches if match.replacements]
-    errors = [ltext[match.offset:match.offset + match.errorlength]
+    errors = [ltext[match.offset:match.offset + match.errorLength]
               for match in matches]
     correct_offset = 0
     for n, match in enumerate(matches):
         frompos, topos = (correct_offset + match.offset,
-                          correct_offset + match.offset + match.errorlength)
+                          correct_offset + match.offset + match.errorLength)
         if ltext[frompos:topos] != errors[n]:
             continue
         repl = match.replacements[0]
